@@ -13,7 +13,7 @@ import yfinance
 
 import lakshmi.constants
 import lakshmi.utils as utils
-from lakshmi.cache import Cacheable, cache
+from lakshmi.cache import Cacheable, cache, prefetch_add
 from lakshmi.table import Table
 
 
@@ -190,6 +190,11 @@ class Asset(ABC):
         """Returns the short name of this asset (ideally < 10 chars)."""
         pass
 
+    def prefetch_add(self):
+        """If possible, add this object to be prefetched in parallel using
+        cache.prefetch_add function."""
+        pass
+
 
 class ManualAsset(Asset):
     """This is a special catch-all asset type that represents an asset whose
@@ -510,6 +515,9 @@ class TickerAsset(TradedAsset, Cacheable):
                 'from Yahoo Finance')
         return self.yticker.info['regularMarketPrice']
 
+    def prefetch_add(self):
+        prefetch_add(self)
+
 
 class VanguardFund(TradedAsset, Cacheable):
     """An asset class representing Vanguard trust fund represented by a
@@ -605,6 +613,9 @@ class VanguardFund(TradedAsset, Cacheable):
         return float(req.json()['currentPrice']
                      ['dailyPrice']['regular']['price'])
 
+    def prefetch_add(self):
+        prefetch_add(self)
+
 
 class _TreasuryBonds(Asset):
     """Class representing a collection of I or EE bonds."""
@@ -770,6 +781,10 @@ class _TreasuryBonds(Asset):
         """Returns short name (same as name)."""
         return self.name()
 
+    def prefetch_add(self):
+        for b in self.bonds():
+            prefetch_add(b)
+
 
 class IBonds(_TreasuryBonds):
     """Class representing a collection of I Bonds."""
